@@ -46,12 +46,14 @@ class ApiResult(object):
         self.body = None
         self.http_code = None
         self.time = None
+        self.size = None
 
         self._data = None
 
     def process(self, response):
         try:
             self._data = json.loads(response, object_hook=from_dict)
+            self.size = len(response)
         except ValueError, e:
             self.body = response
 
